The dest function computes different Liu biasing parameters available in the literature, proposed by different researchers such as given in Liu (1993) <doi:10.1080/03610929308831027>, Liu (2011) <doi:10.1016/j.jspi.2010.05.030>, and Ozkale and Kaciranlar (2007) <doi:10.1080/03610920601126522>.
dest(object, …)
# S3 method for liu
dest(object, …)
# S3 method for dliu
print(x, …)An object of class "liu".
An object of class "dliu" for the print.dest.dliu.
Not presently used in this implementation.
This function returns the list of following estimators of Liu parameter, available in the literature.
By Liu (1993): \(\frac{\sum_{j=1}^p \left[\frac{\alpha_j^2-\sigma^2}{(\lambda_j+1)^2}\right]}{\sum_{j=1}^p\left[\frac{\sigma^2+\lambda_j\times\alpha_j^2}{\lambda_j(\lambda_j+1)^2}\right]}\)
By Liu, (2011): \(\frac{\sum_{j=1}^n \left(\frac{\widetilde{e}_i}{1-g_{ii}}\left(\frac{\widetilde{e}_i}{1-h_{1-ii}}-\frac{\hat{e}_i}{1-h_{ii}}\right)\right)} {\sum_{i=1}^n \left(\frac{\widetilde{e}_i}{1-g_{ii}}-\frac{\hat{e}_i}{1-h_{ii}}\right)^2}\),
where, \(\hat{e}=y_i-x'_i(X'X-x_i x'_i)^{-1}(X'y-x_iy_i)\), \(\widetilde{e}=y_i-x'_i(X'X+I_p-x_i x'_i)^{-1}(X'y-x_iy_i)\), \(G=X(X'X+I_p)^{-1}X'\) and \(H\cong X(X'X)^{-1}X'\).
Liu, (1993): \((1-\hat{\sigma}^2) \left[\frac{\sum_{j=1}^p\left[\frac{1}{\lambda_j(\lambda_j+1)}\right]}{\sum_{j=1}^p\left[\frac{\hat{\alpha}_j^2}{(\lambda_j+1)^2}\right]}\right]\)
By Liu, (1993): \((1-\hat{\sigma}^2)\left[\frac{\sum_{j=1}^p\left[\frac{1}{(\lambda_j+1)}\right]}{\sum_{j=1}^p \left[\frac{\lambda_j\hat{\alpha}_j^2}{(\lambda_j+1)^2}\right]}\right]\).
GCV criterion for selection of optimal \(d\), that is, \(GCV=\frac{SSR_d}{(n-1-trace(H_d))}\), where \(SSR_d\) is residuals sum of squares from Liu regression at certain value of \(d\) and \(trace(H_d)\) is trace of hat matrix from Liu.
returns value of \(d\) at which GCV is minimum.
The dest function computes different biasing parameter for the Liu regression. All these methods are already available in the literature proposed by various authors.
Akdeniz, F. and Kaciranlar, S. (1995). On the Almost Unbiased Generalized Liu Estimators and Unbiased Estimation of the Bias and MSE. Communications in Statistics-Theory and Methods, 24, 1789--1897. http://doi.org/10.1080/03610929508831585.
Imdad, M. U. (2017). Addressing Linear Regression Models with Correlated Regressors: Some Package Development in R (Doctoral Thesis, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan).
Imdadullah, M., Aslam, M., and Altaf, S. (2017). liureg: A comprehensive R Package for the Liu Estimation of Linear Regression Model with Collinear Regressors. The R Journal, 9 (2), 232--247.
Liu, K. (1993). A new Class of Biased Estimate in Linear Regression. Journal of Statistical Planning and Inference, 141, 189--196. http://doi.org/10.1080/03610929308831027.
Liu, X-Q. (2011). Improved Liu Estimator in a Linear Regression Model. Journal of Statistical Planning and Inference,141, 189--196. https://doi.org/10.1016/j.jspi.2010.05.030.
Ozkale, R. M. and Kaciranlar, S. (2007). A Prediction-Oriented Criterion for Choosing the Biasing Parameter in Liu Estimation. Commincations in Statistics-Theory and Methods, 36(10): 1889--1903. http://doi.org/10.1080/03610920601126522.
Liu model fitting liu, Liu residuals residuals.liu, Liu PRESS press.liu, Testing of Liu coefficients summary.liu
# NOT RUN {
mod<-liu(y ~ ., data = as.data.frame(Hald), d = seq(-5, 5, 0.1))
dest(mod)
## Vector of GCV values for each d
dest(mod)$GCV
# }
Run the code above in your browser using DataLab