Learn R Programming

liureg (version 1.1.2)

hatl.liu: Liu Regression: Hat Matrix

Description

The hatl function computes hat matrix of Liu regression (Liu (1993) <doi:10.1080/03610929308831027>).

Usage

hatl(object, …)
# S3 method for liu
hatl(object, …)

Arguments

object

An object of class "liu".

Not presently used in this implementation.

Value

Returns a list of matrix for each biasing parameter \(d\):

hatl

A list of hat matrix for each biasing parameter \(d\).

Details

Hat matrix for scalar or vector values of biasing parameter \(d\) provided as argument to liu function. It is used to compute degrees of freedom for given \(d\), and error degree of freedom etc. The hat matrix can be computed using formula \(X(X'X+I_p)^{-1}(X'X+dI_p)(X'X)^{-1}X'\).

References

Imdad, M. U. (2017). Addressing Linear Regression Models with Correlated Regressors: Some Package Development in R (Doctoral Thesis, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan).

Imdadullah, M., Aslam, M., and Altaf, S. (2017). liureg: A comprehensive R Package for the Liu Estimation of Linear Regression Model with Collinear Regressors. The R Journal, 9 (2), 232--247.

Liu, K. (1993). A new Class of Biased Estimate in Linear Regression. Journal of Statistical Planning and Inference, 141, 189--196. http://doi.org/10.1080/03610929308831027.

See Also

Liu model fitting liu, Liu residuals residuals.liu, Liu PRESS press.liu, Testing of Liu Coefficients summary.liu

Examples

Run this code
# NOT RUN {
mod<-liu(y ~ . , data = as.data.frame(Hald), d = c(-5, -1, 0.2, 0.3))
## Hat matrix for each biasing parameter
hatl(mod)

## Hat matrix for second biasing parameter i.e. d = -1
hatl(mod)[[2]]

## Diagonal element of hat matrix for second biasing parameter
diag(hatl(mod)[[2]])
# }

Run the code above in your browser using DataLab