Akaike, H. (1974). A new look at the Statistical Model Identification. IEEE Transaction on Automatic Control, 9(6), 716--723. https://doi.org/10.1109/TAC.1974.1100705.
Akdeniz, F. and Kaciranlar, S. (1995). On the Almost Unbiased Generalized Liu Estimators and Unbiased Estimation of the Bias and MSE. Communications in Statistics-Theory and Methods, 24, 1789--1897. http://doi.org/10.1080/03610929508831585.
Imdad, M. U. (2017). Addressing Linear Regression Models with Correlated Regressors: Some Package Development in R (Doctoral Thesis, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan).
Imdadullah, M., Aslam, M., and Altaf, S. (2017). liureg: A comprehensive R Package for the Liu Estimation of Linear Regression Model with Collinear Regressors. The R Journal, 9 (2), 232--247.
Liu, K. (1993). A new Class of Biased Estimate in Linear Regression. Journal of Statistical Planning and Inference, 141, 189--196. http://doi.org/10.1080/03610929308831027.
Schwarz, G. (1978). Estimating the Dimension of a Model. Annals of Statistics, 6(2), 461--464. https://projecteuclid.org/euclid.aos/1176344136.