The lstats function computes the Liu regression related statistics such as variance, estimated squared bias, MSE, R-squared and adjusted R-squared etc. These statistics are computed by following Liu (1993) <doi:10.1080/03610929308831027>; Akdeniz, F. and Kaciranlar, S. (1995) <doi:10.1080/03610929508831585>; Cule, E. and De Iorioa, M. (2012); Hastie, T. and Tibshirani, R. (1990); and Mallows (1973) <doi:10.2307/1267380>.
lstats(object, …)
# S3 method for liu
lstats(object, …)
# S3 method for lstats
print(x, …)An object of class "liu".
An object of class "liu" for print.lstats.liu.
Not presently used in this implementation.
Residual effective degrees of freedom for given biasing parameter \(d\) from Hastie and Tibshirani (1990), i.e., \(n-trace(2H_d)-H_d t(H_d)\).
Computation of \(\hat{\sigma}^2\) from Liu regression.
Mallows \(C_p\) like statistics for given biasing parameter \(d\)
Variance of Liu regression for given biasing parameter \(d\).
Estimated squared bias of Liu regression for given biasing parameter \(d\).
Total MSE value for given biasing parameter \(d\).
F-statistics value for testing of the significance of the Liu regression estimator computed for given biasing parameter \(d\).
R-squared for given biasing parameter \(d\).
Adjusted R-squared for given biasing parameter \(d\).
Minimum MSE value for a certain value of biasing parameter \(d\).
Sum of squares of error from Liu regression for each biasing parameter \(d\).
The lstats function computes the Liu regression related statistics which may help in selecting appropriate optimal value of biasing parameter \(d\). If value of \(d\) is one then these statistics are equivalent to the relevant OLS statistics.
Akdeniz, F. and Kaciranlar, S. (1995). On the Almost Unbiased Generalized Liu Estimators and Unbiased Estimation of the Bias and MSE. Communications in Statistics-Theory and Methods, 24, 1789--1897. http://doi.org/10.1080/03610929508831585.
Cule, E. and De lorioa, M. (2012). A semi-Automated method to guide the choice of ridge parameter in ridge regression. arXiv:1205.0686v1[stat.AP]. https://arxiv.org/abs/1205.0686v1.
Hastie, T. and Tibshirani, R. (1990). Generalized Additive Models. Chapman \& Hall.
Imdad, M. U. (2017). Addressing Linear Regression Models with Correlated Regressors: Some Package Development in R (Doctoral Thesis, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan).
Imdadullah, M., Aslam, M., and Altaf, S. (2017). liureg: A comprehensive R Package for the Liu Estimation of Linear Regression Model with Collinear Regressors. The R Journal, 9 (2), 232--247.
Liu, K. (1993). A new Class of Biased Estimate in Linear Regression. Journal of Statistical Planning and Inference, 141, 189--196. http://doi.org/10.1080/03610929308831027.
Mallows, C. L. (1973). Some Comments on Cp. Technometrics, 15: 661--675. http://doi.org/10.2307/1267380.
Liu model fitting liu, Liu residuals residuals.liu, Liu PRESS press.liu, Testing of Liu Coefficients summary.liu
# NOT RUN {
mod<-liu(y~., data = as.data.frame(Hald), d = seq(-5, 5, 0.1), scaling = "centered")
lstats(mod)
# }
Run the code above in your browser using DataLab