The press.liu function computes predicted residual sum of squares (PRESS), computed from by following Ozkale and Kaciranlar (2007) <doi:10.1080/03610920601126522>.
press(object, predr = FALSE, …)
# S3 method for liu
press(object, predr = FALSE, …)An object of class "liu".
If TRUE then predicted residuals are returned.
Not presently used in this implementation.
The press.liu produces a vector of PRESS for scalar or vector values of biasing parameter \(d\). If argument predr is TRUE then predicted residuals are returned instead of predicted residual sum of squares.
For all of the n leave-one-out predicted residual sum of squares is calculated by fitting full regression model. PRESS is computed by using, \(\sum (\hat{e}_{d(i)})^2\) or \(\sum \left[\frac{\hat{e}_{di}}{1-h_{1-ii}}-\frac{e_i}{(1-h_{1-ii})(1-h_{ii})}(h_{1-ii}-\widetilde{H}_{d-ii})\right]^2\) , where \(h_{ii}=X(X'X)^{-1} X'\)'s ith diagonal element, \(h_{1-ii}=X(X'X+I)^{-1}X'\)'s ith diagonal element and \(\hat{e}_{di}\) is the ith residual at specific value of \(d\).
Akdeniz, F. and Kaciranlar, S. (1995). On the Almost Unbiased Generalized Liu Estimators and Unbiased Estimation of the Bias and MSE. Communications in Statistics-Theory and Methods, 24, 1789--1897. http://doi.org/10.1080/03610929508831585.
Allen, D. M. (1971). Mean Square Error of Prediction as a Criterion for Selecting Variables. Technometrics, 13, 469-475. http://www.jstor.org/stable/1267161.
Allen, D. M. (1974). The Relationship between Variable Selection and Data Augmentation and Method for Prediction. Technometrics, 16, 125-127. http://www.jstor.org/stable/1267500.
Imdad, M. U. (2017). Addressing Linear Regression Models with Correlated Regressors: Some Package Development in R (Doctoral Thesis, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan).
Imdadullah, M., Aslam, M., and Altaf, S. (2017). liureg: A comprehensive R Package for the Liu Estimation of Linear Regression Model with Collinear Regressors. The R Journal, 9 (2), 232--247.
Liu, K. (1993). A new Class of Biased Estimate in Linear Regression. Journal of Statistical Planning and Inference, 141, 189--196. http://doi.org/10.1080/03610929308831027.
Ozkale, R. M. and Kaciranlar, S. (2007). A Prediction-Oriented Criterion for Choosing the Biasing Parameter in Liu Estimation. Commincations in Statistics-Theory and Methods, 36(10): 1889--1903. http://doi.org/10.1080/03610920601126522.
The ridge model fitting liu, Liu residual residuals, Liu predicted value predict
# NOT RUN {
mod<-liu(y~., data = as.data.frame(Hald), d = seq(-5, 5, 0.1))
## PRESS
press(mod)
## Predicted residual
press(mod, predr = TRUE)
# }
Run the code above in your browser using DataLab