The summary method for class "liu" for scalar or vector biasing parameter \(d\).
# S3 method for liu
summary(object, …)
# S3 method for summary.liu
print(x, digits = max(4, getOption("digits") - 3),
signif.stars = getOption("show.signif.stars"), …)An "liu" object, typically generated by a call to liu.
An object of class summary.liu for the print.summary.liu.
logical: if TRUE, p-values are additionally encoded visually as significance starts in order to help scanning of long coefficient tables. It default to the show.signif.stars slot of options.
The number of significant digits to use when printing.
Not presently used in this implementation.
The function summary computes and returns a list of summary statistics of the fitted linear Liu regression model for scalar or vector value biasing parameter \(d\) given as argument in liu function.
A \(p \times 5\) matrix with columns for the scaled estimated, descaled estimated coefficients, scaled standard error, scaled t-statistics, and corresponding p-value (two-tailed). The Intercept term is computed by the relation
\(\hat{\beta}_{od}=\overline{y}-\sum_{j=1}^{p}\overline{X}_j \hat{\beta}_{jd}\).
The standard error of intercept term is computed as, \(SE(\hat{\beta}_{0d})=\sqrt{Var(\overline{y}) +\overline{X}_j^2 diag[Cov(\hat{\beta}_{jd})]}\).
Liu related statistics of R-squared, adjusted R-squared, F-statistics for testing of coefficients, AIC and BIC values for given biasing parameter \(d\).
Minimum MSE value for given biasing parameter \(d\).
Value of \(d\) at which MSE is minimum.
print.summary.liu tries to be smart about formatting the coefficients, standard errors etc. and additionally gives 'significance stars' if signif.stars is TRUE.
Aslam, M. (2014). Using Heteroscedasticity-Consistent Standard Errors for the Linear Regression Model with Correlated Regressors. Communication in Statistics-Simulation and Computation, 43, 2353--2373. http://doi.org/10.1080/03610918.2012.750354.
Cule, E. and De lorio, M. (2012). A semi-Automatic method to guide the choice of ridge parameter in ridge regression. arXiv:1205.0686v1 [stat.AP]. https://arxiv.org/abs/1205.0686v1.
Halawa, A. And El-Bassiouni, M. (2000). Tests of Regression Coefficients Under Ridge Regression Models. Journal of Statistical Computation and Simulation, 65, 341--356. https://www.tandfonline.com/doi/abs/10.1080/00949650008812006.
Hastie, T. and Tibshirani, R. (1990). Generalized Additive Models. Chapman & Hall.
Imdad, M. U. (2017). Addressing Linear Regression Models with Correlated Regressors: Some Package Development in R (Doctoral Thesis, Department of Statistics, Bahauddin Zakariya University, Multan, Pakistan).
Imdadullah, M., Aslam, M., and Altaf, S. (2017). liureg: A comprehensive R Package for the Liu Estimation of Linear Regression Model with Collinear Regressors. The R Journal, 9 (2), 232--247.
The Liu model fitting liu, Liu residual residuals, Liu predicted value predict
# NOT RUN {
mod <- liu(y~., as.data.frame(Hald), d = c(-2, -1.47218, 0, 0.5, 1) )
summary(mod)
## coefficients for first biasing parameter
summary(mod)$summaries[[1]]$coefficients
summary(mod)$summaries[[1]][[1]]
## Liu related statistics from summary function
summary(mod)$summaries[[1]]$stats
# }
Run the code above in your browser using DataLab