predict.liu produces a vector of prediction or a matrix of predictions for scalar or vector values of biasing parameter \(d\).
Details
The predict.liu function predicted values, obtained by evaluating the regression function in the frame newdata which defaults to model.frame (object). If newdata is omitted the predictions are based on the data used for the fit. In that case how cases with missing values in the original fit are handled is determined by the na.action argument of that fit. If na.action=na.omit omitted cases will not appear in the predictions, whereas if na.action=na.exclude they will appear (in predictions), with value NA.